'use strict';

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function AppBundler() {
  var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];
  var context = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

  var project = options.project || context.project || this;

  return _promise2.default.all(project.allAssets.map(function (asset) {
    return project.readFile(asset.paths.absolute).then(function (raw) {
      asset.raw = raw;
      asset.assetWasImported();
      return asset;
    });
  })).then(function () {
    return project.pickResult('settings', 'copy', 'entities', 'gitInfo', 'manifest');
  }).then(function (bundle) {
    if (!options.full) {
      return (0, _extends3.default)({}, bundle, { content: { docs: {}, scripts: {} } });
    }

    return (0, _extends3.default)({}, bundle, {
      content: {
        docs: project.docs.mapValues(function (doc) {

          if (doc.id && doc.id.match(/bundle/)) {
            return {};
          }

          doc.ensureIndexes();

          return {
            html: doc.html.content,
            indexes: doc.indexes,
            transformed: doc.transformed,
            raw: doc.raw,
            id: doc.id,
            metadata: doc.metadata,
            paths: doc.paths
          };
        }),
        scripts: project.scripts.mapValues(function (script) {
          if (script.id.match(/bundle/) || script.paths.absolute.match(/(dlls|themes)/)) {
            return {};
          } else {
            return (0, _extends3.default)({}, script, { paths: script.paths, raw: script.raw, metadata: script.metadata });
          }
        })
      }
    });
  }).then(function (bundle) {
    project.outputJson('src/app.bundle.json', bundle);
    return bundle;
  }).then(function (bundle) {
    console.log('Bundled app ' + bundle.manifest.version + ' ' + bundle.gitInfo.abbreviatedSha);
  });
};