module.exports = function AppBundler (options = {}, context = {}) {
  const project = options.project || context.project || this

  return Promise.all(project.allAssets.map(
    (asset) => project
      .readFile(asset.paths.absolute)
      .then(raw => {
        asset.raw = raw
        asset.assetWasImported()
        return asset
      })
  ))
  .then(() => {
    return project.pickResult(
       'settings',
       'copy',
       'entities',
       'gitInfo',
       'manifest'
    )
  })
  .then((bundle) => {
    if (!options.full) { return {...bundle, content: {docs:{},scripts:{}} }}

    return {
      ...bundle,
      content: {
        docs: project.docs.mapValues(doc => {

          if (doc.id && doc.id.match(/bundle/)) {
            return {}
          }

          doc.ensureIndexes()

          return {
            html: doc.html.content,
            indexes: doc.indexes,
            transformed: doc.transformed,
            raw: doc.raw,
            id: doc.id,
            metadata: doc.metadata,
            paths: doc.paths
          }
        }),
        scripts: project.scripts.mapValues(script => {
          if (script.id.match(/bundle/) || script.paths.absolute.match(/(dlls|themes)/)) {
            return {}
          } else {
            return { ...script, paths: script.paths, raw: script.raw, metadata: script.metadata }
          }
        })
      }
    }
  })
  .then((bundle) => {
    project.outputJson( 'src/app.bundle.json', bundle)
    return bundle
  })
  .then((bundle) => {
    console.log(`Bundled app ${bundle.manifest.version} ${ bundle.gitInfo.abbreviatedSha }`)
  })
}
